// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: dataset_inline.h,v 1.6 1998/10/09 17:57:27 jochen Exp $



#ifndef KROT_DATASET_INLINE_H
#define KROT_DATASET_INLINE_H


#include "krot.h"

#include <qcolor.h>
#include <qstring.h>

#include <sys/types.h>


inline DataSet::DataSet( KRotData *krotdata )
    : clr( blue ), data( 0 ), dlta( 1 ), krotData( krotdata ),
      mx( 0 ), mn( 0 ), offset( 0 ),
      scalg( 1 ), siz( 0 ), strt( 0 ), stp( 0 )
{
    return;
}



inline DataSet::DataSet( const DataSet& set )
    : clr( set.clr ), data( new int64_t[ set.siz ] ), dlta( set.dlta ),
      krotData( set.krotData ), mx( set.mx ), mn( set.mn ), nam( set.nam ),
      offset( set.offset ), scalg( set.scalg ), siz( set.siz ),
      strt( set.strt ), stp( set.stp )
{
    for( unsigned int i=0; i<siz; i++ )
	data[ i ] = set.data[ i ];
    return;
}




inline DataSet::~DataSet()
{
    delete [] data;
    return;
}



inline bool DataSet::operator<( const DataSet& set ) const
{ 
    return nam < set.nam;
}



inline bool DataSet::operator==( const DataSet& set ) const
{ 
    return ( this == &set );
}



inline const QColor& DataSet::color() const
{
    return clr;
}



inline unsigned int DataSet::delta() const
{
    return dlta;
}



inline int64_t DataSet::max() const
{
    return mx;
}



inline int64_t DataSet::min() const
{
    return mn;
}



inline const QString& DataSet::name() const
{
    return nam;
}

 

inline const QString DataSet::shortName() const
{
    // findRev returns the last occurence of '/', we want the short name to
    // start behind it.
    return nam.mid( nam.findRev( "/" ) + 1, nam.length() );
}

 

inline const double DataSet::scaling() const
{
    return scalg;
}



inline void DataSet::setColor( const QColor& color )
{
    clr = color;
    return;
}



inline void DataSet::setScaling( const double scaling )
{
    scalg = scaling;
    return;
}



inline unsigned int DataSet::size() const
{
    return siz;
}



inline int64_t DataSet::start() const
{
    return strt;
}



inline int64_t DataSet::stop() const
{
    return stp;
}


#endif
